/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2004 Creation P.Delrieu
 *  2004 Modified by Romain Beaugrand
 * 
 */
package org.openmobileis.database.fastobjectdb.db.transaction;

import java.util.HashMap;

import org.openmobileis.database.fastobjectdb.db.exception.FODBException;

/**
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public final class TransactionManager {
	private HashMap transactionListbythread;
	private HashMap transactionFileListbyCollection;
  /**
   * 
   */
  public TransactionManager() {
    super();
		transactionListbythread = new HashMap(10);
		transactionFileListbyCollection = new HashMap(20);
  }
  
  private Transaction getTransaction()	{
  	Thread th = Thread.currentThread();
  	Transaction ret = (Transaction)transactionListbythread.get(th);
  	if (ret==null)	{
  		ret = new Transaction();
			transactionListbythread.put(th, ret);
  	}
  	return ret;
  }
  
  public synchronized void registerTransactionFile(TransactionFile file, String collectionName)	{
		transactionFileListbyCollection.put(collectionName, file);
  }
  
	public synchronized void enterTransaction(String collectionName)	throws FODBException {
		TransactionFile file = (TransactionFile)transactionFileListbyCollection.get(collectionName);
		if (file != null)	{
			this.getTransaction().addTransactionFile(file);
		} else	{
			throw new FODBException("ERROR TransactionManager Unregistered Collection :"+collectionName+" try to enter transaction.");
		}
	}
  
  public void begin()	throws FODBException {
		this.getTransaction().begin();
  }
  
  public void commit() throws FODBException	{
		boolean effective = this.getTransaction().commit();
		if (effective)	{
			transactionListbythread.remove(Thread.currentThread());
		}
  }
  
  public void rollback() throws FODBException	{
		boolean effective = this.getTransaction().rollback();
		if (effective)	{
			transactionListbythread.remove(Thread.currentThread());
		}
  }

}
