/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2005 Creation P.Delrieu
 * 
 */

package org.openmobileis.modules.profils.embedded.data;

import org.openmobileis.common.util.collection.Array;

/**
 * Title:        OpenMobileIS project source <BR>
 * Description: A profil channel.
 * A channel is a name and a collection of rubrics.
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public class EmbeddedProfilChannel {

  protected String name;
  protected Array rubrics;

  public EmbeddedProfilChannel() {
   rubrics = new Array(1);
  }

  public EmbeddedProfilChannel(String channelName) {
    this();
    this.name = channelName;
   }

  public void setName (String name) {
    this.name = name;
  }

  public String getName() {
    return name;
  }

  public void addRubic(EmbeddedProfilRubric rub) {
    rubrics.add(rub);
  }

  public Array getRubrics() {
    return rubrics;
  }

  public EmbeddedProfilRubric getRubric (int pos) {
    return (EmbeddedProfilRubric)rubrics.get(pos);
  }

  public int getRubricSize() {
    return rubrics.size();
  }

  public void setSelection (boolean selected) {
     for (int i=0; i<rubrics.size();i++) {
        ((EmbeddedProfilRubric)rubrics.get(i)).setSelection(selected);
    }
  }

  // Could be optimized...
  public EmbeddedProfilRubric getRubric (String rubricName) {
    for (int i=0; i<rubrics.size();i++) {
        if (((EmbeddedProfilRubric)rubrics.get(i)).getName().equals(rubricName))
            return (EmbeddedProfilRubric)rubrics.get(i);
    }
    return null;
  }

  public boolean isSelected() {
    for (int i=0; i<rubrics.size();i++) {
      if (!((EmbeddedProfilRubric)rubrics.get(i)).isSelected())
        return false;
    }
    return true;
  }

  public String getXmlDescription() {
    StringBuffer buffer = new StringBuffer();
    buffer.append("<channel>\n");
    buffer.append("<name>");
    buffer.append(name);
    buffer.append("</name>\n");
    for (int i=0; i < rubrics.size(); i++)
      buffer.append(((EmbeddedProfilRubric)rubrics.get(i)).getXmlDescription());
    buffer.append("</channel>\n");
    return buffer.toString();
  }

}