/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2005 Creation P.Delrieu
 * 
 */

package org.openmobileis.modules.profils.embedded.data;

import org.openmobileis.common.util.collection.Array;
import org.openmobileis.embedded.webserver.WebServer;
import com.microstar.xml.XmlParser;
import java.io.StringReader;
import org.openmobileis.common.util.log.*;
import org.openmobileis.common.util.exception.ServerException;


/**
 * Title:        OpenMobileIS project source <BR>
 * Description: EmbeddedProfilChannel Manager. Use to get channel from profil.
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public class EmbeddedProfilChannelManager {

  private static EmbeddedProfilChannelManager manager;
  private String profilFile;
  private Array profilChannels;

  public static EmbeddedProfilChannelManager getManager() {
    if (manager == null)  {
      synchronized(org.openmobileis.modules.profils.embedded.data.EmbeddedProfilChannelManager.class) {
        if (manager == null)  {
          manager = new EmbeddedProfilChannelManager();
        }
      }
    }
    return manager;
  }

   public EmbeddedProfilChannelManager() {
   // profilFile = WebServer.propsDir + "profilData";
  }

  /*
  * Get the channels / rubrics from initial profil and return them
  * but not selected
  */
  public Array getProfilChannels() {
    if(profilChannels != null) {
      return profilChannels;
    }
    try {
        java.io.FileInputStream file = new java.io.FileInputStream(this.profilFile);
        StringBuffer buffer = new StringBuffer();
        byte[] buf = new byte[512];
        int len;
        while ( ( len = file.read( buf ) ) != -1 ) {
          buffer.append(new String(buf, 0, len));
          }
        file.close();
        profilChannels = this.getChannels(buffer.toString(), true);

        return profilChannels;
    } catch (java.io.FileNotFoundException e) {
      LogManager.traceError(LogServices.WEBSERVICE, "Can not read profil file : " + this.profilFile);
    } catch (java.io.IOException e) {
      LogManager.traceError(LogServices.WEBSERVICE, "Can not read profil file : " + this.profilFile);
    }
      return null;
  }

  /*
  * Get the channels / rubrics from initial profil and return them
  * but not selected
  */
  public Array getPDAAvailableChannels() {
    try {
        java.io.FileInputStream file = new java.io.FileInputStream(this.profilFile);
        StringBuffer buffer = new StringBuffer();
        byte[] buf = new byte[512];
        int len;
        while ( ( len = file.read( buf ) ) != -1 ) {
          buffer.append(new String(buf, 0, len));
          }
        file.close();
        return this.getChannels(buffer.toString(), false);
    } catch (java.io.FileNotFoundException e) {
      LogManager.traceError(LogServices.WEBSERVICE, "Can not read profil file : " + this.profilFile);
    } catch (java.io.IOException e) {
      LogManager.traceError(LogServices.WEBSERVICE, "Can not read profil file : " + this.profilFile);
    }
      return null;
  }

  /*
  *  Once the synchro manager get the response from openmobileis server for the profil, it asks
  * the receiver to store it (in a file).
  */
  public void setInitialProfil(String xmldata) {
   try {
    java.io.FileOutputStream file = new java.io.FileOutputStream(this.profilFile);
    file.write(xmldata.getBytes());
    file.close();
    profilChannels = null;
   } catch (java.io.IOException e) {
      LogManager.traceError(LogServices.WEBSERVICE, "Can not read profil file : " + this.profilFile);
   }
  }

  /*
  * Parse XML elements and builds channels / rubrics
  * @return: CyberArray containing EmbeddedProfilChannel objects
  */
  public Array getChannels (String xmlData, boolean takeSelectionAccount) {
    try {
      StringReader reader = new StringReader(xmlData);
      XmlParser parser = new XmlParser();
      EmbeddedProfilChannelsParser handler = new EmbeddedProfilChannelsParser(takeSelectionAccount);
      parser.setHandler(handler);
      parser.parse(null, null, reader);
      return handler.getChannels();
    } catch (Exception e) {
      LogManager.trace(new ServerException("Error during parsing XML data for profils ",e));
      return null;
    }
  }

 /*
 * Return the channel/rubric selected for the profil
 * the choosen is an url like channel/rubric?context1=value1,channel2/rubric?context2=value2 ended
 * by a carriage return.
 */
 public String getChannelListData (String xmlData) {
    Array channels = this.getChannels(xmlData, true);
    StringBuffer buffer = new StringBuffer();
    for (int i=0; i < channels.size(); i++) {
        EmbeddedProfilChannel channel = (EmbeddedProfilChannel)channels.get(i);
        for (int j=0; j < channel.rubrics.size(); j++) {
            EmbeddedProfilRubric rubric = channel.getRubric(j);
            if (rubric.isSelected) {
              buffer.append(channel.getName());
              buffer.append("/");
              buffer.append(rubric.getName());
              buffer.append(",");
            }
          } // end for rubric
    }// end for channels
    // remove the last semicolon and replace it by a carriage return (can not use #replace method
    // from StringBuffer, not implemented in PersonnalJava VM
    String result = buffer.toString();
    return result.substring(0, buffer.length()-1) + "\n";
 }

 /*
 * Return the xml data relative to the channels stored in the array
 */
 public String getXmlDescription (Array channels) {
  StringBuffer buffer = new StringBuffer();
  for (int i=0; i < channels.size(); i++) {
      buffer.append( ((EmbeddedProfilChannel)channels.get(i)).getXmlDescription());
  }
   return buffer.toString();
 }


 // test program
  public static void main (String[] args) {
  //  WebServer.propsDir = "\\Program Files\\Java\\properties\\";
    Array channels = EmbeddedProfilChannelManager.getManager().getProfilChannels();
    System.out.println("Size : " + channels.size());
  }



}